﻿using System;
using System.Collections.Generic;
//using System.Linq;
using System.Text;

using System.Windows.Forms;

using System.Drawing;
using System.Runtime.InteropServices;

using System.IO;
using System.ComponentModel;

namespace WindowsApplication1
{
    class DrvCombo : ComboBox
    {
        public DrvCombo()
        {
            if (LicenseManager.UsageMode !=
                      LicenseUsageMode.Designtime)
            {
                DriveInfo[] Drives =
                              DriveInfo.GetDrives();
                foreach (DriveInfo Drive in Drives)
                {
                    base.Items.Add(Drive);
                }
                base.SelectedIndex = 1;
                base.DrawMode =
                     DrawMode.OwnerDrawFixed;
                base.DropDownStyle =
                      ComboBoxStyle.DropDownList;
            }
        }
        protected override void
           OnDrawItem(DrawItemEventArgs e)
        {
            
            if (e.Index == -1) return;
            DriveInfo drive = (DriveInfo)
                   base.Items[e.Index];
            Icon icon;
            switch (drive.DriveType)
            {
                case (DriveType.Fixed):
                    icon = ShellIcons.HardDisk;
                    break;
                case (DriveType.CDRom):
                    icon = ShellIcons.CDROM;
                    break;
                case (DriveType.Network):
                    icon = ShellIcons.NetDisk;
                    break;
                case (DriveType.Removable):
                    icon = ShellIcons.FloppyDisk;
                    break;
                default:
                    icon = ShellIcons.UnknownDisk;
                    break;
            }
            Rectangle iconbox = new Rectangle(
                            e.Bounds.X, e.Bounds.Y,
                              e.Bounds.Height, e.Bounds.Height);
            e.DrawBackground();
            e.Graphics.DrawIcon(icon, iconbox);
            icon.Dispose();
            string text = drive.Name;
            if (drive.IsReady)
            {
                if (drive.VolumeLabel != "")
                {
                    text = text + " (" + drive.VolumeLabel + ")";
                }
            }
            e.Graphics.DrawString(text,
                     e.Font,
                       new SolidBrush(e.ForeColor),
                       e.Bounds.X + iconbox.Width + 1,
                       e.Bounds.Y);
            if (e.State == DrawItemState.Focus)
            {
                e.DrawFocusRectangle();
            }
        
 
    }
        
    }
    
    static class ShellIcons
    {

        private const int Floppy = 6;
        private const int Hard = 8;
        private const int Net = 9;
        private const int CD = 11;
        private const int RAM = 12;
        private const int Unknown = 53;

        [DllImport("shell32.dll", EntryPoint = "ExtractIcon")]
        extern static IntPtr ExtractIcon(
     IntPtr hInst,
     string lpszExeFileName,
     int nIconIndex);


        const string ShellIconsLib = @"C:\WINDOWS\System32\shell32.dll";




        static public Icon FloppyDisk
        {
            get { return GetIcon(Floppy); }
        }

        static public Icon HardDisk
        {
            get { return GetIcon(Hard); }
        }

        static public Icon NetDisk
        {
            get { return GetIcon(Net); }
        }

        static public Icon CDROM
        {
            get { return GetIcon(CD); }
        }

        static public Icon RamDisk
        {
            get { return GetIcon(RAM); }
        }
        static public Icon UnknownDisk
        {
            get { return GetIcon(Unknown); }
        }


        static public Icon GetIcon(int index)
        {
            IntPtr Hicon = ExtractIcon(IntPtr.Zero, ShellIconsLib, index);
            Icon icon = Icon.FromHandle(Hicon);

            return icon;


        }
    }
}
